Class: Ultrasafeai::Embeddings::Types::CreateEmbeddingsRequestInput

Inherits:
Internal::Types::Model show all
Extended by:
Internal::Types::Union
Defined in:
lib/ultrasafeai/embeddings/types/create_embeddings_request_input.rb

Overview

Input text to embed, encoded as a string or array of tokens. To embed multiple inputs in a single request, pass an array of strings or array of token arrays. The input must not exceed the max input tokens for the model (8192 tokens for all embedding models), cannot be an empty string, and any array must be 2048 dimensions or less. All embedding models enforce a maximum of 300,000 tokens summed across all inputs in a single request.

Method Summary

Methods included from Internal::Types::Union

coerce, discriminant, load, member, members, type_member?

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Constructor Details

This class inherits a constructor from Ultrasafeai::Internal::Types::Model