Class: Ultrasafeai::Types::ChatCompletionToolChoiceOption

Inherits:
Internal::Types::Model show all
Extended by:
Internal::Types::Union
Defined in:
lib/ultrasafeai/types/chat_completion_tool_choice_option.rb

Overview

Controls which (if any) tool is called by the model.

  • none — the model will not call any tool and instead generates a message. - auto — the model can pick between generating a message or calling tools. - required — the model must call one or more tools. - Named function: {"type": "function", "function": {"name": "my_fn"}} forces a specific function. - Named custom: {"type": "custom", "custom": {"name": "my_tool"}} forces a specific custom tool. - Allowed tools: {"type": "allowed_tools", "allowed_tools": {"mode": "auto", "tools": [...]}} restricts the model to a subset of tools.

Method Summary

Methods included from Internal::Types::Union

coerce, discriminant, load, member, members, type_member?

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Constructor Details

This class inherits a constructor from Ultrasafeai::Internal::Types::Model